require 'httparty'
require 'crack'

class Bipbop
  include HTTParty
  base_uri 'irql.bipbop.com.br'

  parser(
    Proc.new do |body, format|
      Crack::XML.parse(body)
    end
  )

  attr_reader :api_key

  def initialize(api_key = nil)
    @api_key = api_key || ENV['BIPBOP_API_KEY']
  end

  def cpfcnpj(params)
    request(:bipbopjs, :cpfcnpj, params)
  end

  def social(params)
    request(:social, :consulta, params)
  end

  def perfileconomico(params)
    request(:ecommerce, :perfileconomico, params)
  end

  private

    def irql(database, table, params)
      conditions = []
      params.each_pair do |key, value|
        conditions << "'#{key.upcase}' = '#{value}'"
      end
      "SELECT FROM '#{database.upcase}'.'#{table.upcase}' WHERE #{conditions.join(" AND ")}"
    end

    def request(database, table, params)
      @response = self.class.get("/", query(irql(database, table, params)))
      if @response.code == 200
        body = @response["IRQL"]['body']
        body.merge('gender' => body['name'].attributes['gender']) rescue body
      end
    end

    def query(q)
      { :query => {'q' => q, 'apiKey' => @api_key}}
    end

end
